package com.entity38.http;

import java.io.IOException;
import javax.servlet.http.HttpSession;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class Rewrite {

  /** Fuehrt einen Redirect aus falls die Session neu ist und gibt 
      true zurueck. Besteht die Session schon, ist bereits die 
      Session-ID bekannt und ein Redirect nicht notwendig. 
      In dem Fall wird false zurueckgegeben.
      
      <p> Der Code kann auch direkt in die JSP-Seiten eigefuegt 
      werden, aber so ist die Funktion auch fuer Servlets
      zugaenglich.
  */

  public static boolean redirect(HttpServletRequest request, 
                                 HttpServletResponse response) 
                                 throws IOException {
    HttpSession session = request.getSession();
    if(session.isNew()) {
      // Protokoll: http oder https
      String url = request.getScheme() + "://";
      // Name des Server: z.B. localhost
      url += request.getServerName();
      // Server Port falls ungleich 80
      if(request.getServerPort() != 80) {
        url += ":" + Integer.toString(request.getServerPort());
      }
      // Session-ID in den Pfad schreiben
      url += "/SID_" + session.getId();
      // Den Pfad zum Skript aus der URL anhaengen
      String filename = request.getRequestURI();
      // Falls bereits eine Session-ID im Pfad ist, diese 
      // herrausfiltern. Das kommt z.B. vor wenn die Session
      // bereits abgelaufen ist.
      if(filename.substring(0,5).equals("/SID_")) {
        filename = filename.substring(5);
        filename = filename.substring(filename.indexOf('/'));
      }
      url += filename;
      // Den Query-String an die URL haengen
      if(request.getQueryString() != null) {
        url += "?" + request.getQueryString();
      }
      // Dafuer sorgen, dass der Redirect nicht gecached wird
      response.setHeader("Pragma", "no-cache");
      response.setHeader("Cache-Control", "private");
      response.setHeader("Expires", "0");
      // Redirect senden
      response.sendRedirect(url);
    return true;
    } else {
      return false;
    }
  }
}
